.. include:: ./readme.rst

=================
Table of contents
=================

.. toctree::
   :maxdepth: 2

   installation
   guide
   colorspace
   recipes
   changes


..
   Indices and tables
   ==================
   
   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
